"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useShare = exports.ShareProvider = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _reactNativeReanimated = _interopRequireWildcard(require("react-native-reanimated"));

var _reactNativeAppearance = require("react-native-appearance");

var _reactNativeRedash = require("react-native-redash");

var _useColor = require("./utils/useColor");

var _useTranslations = require("./localizations/useTranslations");

var _ShareHeader = _interopRequireDefault(require("./components/ShareHeader"));

var _ShareDetails = _interopRequireDefault(require("./components/ShareDetails"));

var _ButtonRow = _interopRequireDefault(require("./components/ButtonRow"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const defaultTypes = ['Sms', 'Twitter', 'LinkedIn', 'Mail', 'Copy', 'More'];
const ShareContext = (0, _react.createContext)({
  share: () => {}
});

const ShareProvider = ({
  children,
  language,
  types = defaultTypes
}) => {
  const {
    backgroundPrimary
  } = (0, _useColor.useColor)();
  const [isDisplaying, setIsDisplaying] = (0, _react.useState)(false);
  const transition = (0, _reactNativeRedash.useTransition)(isDisplaying);
  const [details, setDetails] = (0, _react.useState)({});
  const opacity = (0, _reactNativeReanimated.interpolate)(transition, {
    inputRange: [0, 1],
    outputRange: [0, 0.5]
  });
  const transform = [{
    translateY: (0, _reactNativeReanimated.interpolate)(transition, {
      inputRange: [0, 1],
      outputRange: [500, 0]
    })
  }];

  const share = props => {
    setDetails(props);
    setIsDisplaying(true);
  };

  const close = () => setIsDisplaying(false);

  return /*#__PURE__*/_react.default.createElement(_reactNativeAppearance.AppearanceProvider, null, /*#__PURE__*/_react.default.createElement(_useTranslations.LocalizationProvider, {
    language: language
  }, /*#__PURE__*/_react.default.createElement(ShareContext.Provider, {
    value: {
      share
    }
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.content
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.container
  }, children), /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, {
    pointerEvents: isDisplaying ? 'auto' : 'none',
    style: [_reactNative.StyleSheet.absoluteFillObject, styles.overlay, {
      opacity
    }]
  }, isDisplaying && /*#__PURE__*/_react.default.createElement(_reactNative.TouchableWithoutFeedback, {
    style: styles.container,
    onPress: close
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.container
  }))), /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, {
    style: [styles.modal, {
      transform
    }]
  }, /*#__PURE__*/_react.default.createElement(_ShareHeader.default, null), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.innerContainer, {
      backgroundColor: backgroundPrimary
    }]
  }, /*#__PURE__*/_react.default.createElement(_ShareDetails.default, details), /*#__PURE__*/_react.default.createElement(_ButtonRow.default, {
    types: types,
    details: details,
    close: close
  })))))));
};

exports.ShareProvider = ShareProvider;

const styles = _reactNative.StyleSheet.create({
  container: {
    flex: 1
  },
  content: {
    flex: 1,
    position: 'relative'
  },
  innerContainer: {
    flex: 1,
    paddingBottom: 60
  },
  overlay: {
    flex: 1,
    backgroundColor: 'black'
  },
  modal: {
    position: 'absolute',
    bottom: 0,
    right: 0,
    left: 0
  }
});

const useShare = () => (0, _react.useContext)(ShareContext);

exports.useShare = useShare;
//# sourceMappingURL=index.js.map