import React, { useState, createContext, useContext } from 'react';
import { View, StyleSheet, TouchableWithoutFeedback } from 'react-native';
import Animated, { interpolate } from 'react-native-reanimated';
import { AppearanceProvider } from 'react-native-appearance';
import { useTransition } from 'react-native-redash';
import { useColor } from './utils/useColor';
import { LocalizationProvider } from './localizations/useTranslations';
import ShareHeader from './components/ShareHeader';
import ShareDetails from './components/ShareDetails';
import ButtonRow from './components/ButtonRow';
const defaultTypes = ['Sms', 'Twitter', 'LinkedIn', 'Mail', 'Copy', 'More'];
const ShareContext = createContext({
  share: () => {}
});

const ShareProvider = ({
  children,
  language,
  types = defaultTypes
}) => {
  const {
    backgroundPrimary
  } = useColor();
  const [isDisplaying, setIsDisplaying] = useState(false);
  const transition = useTransition(isDisplaying);
  const [details, setDetails] = useState({});
  const opacity = interpolate(transition, {
    inputRange: [0, 1],
    outputRange: [0, 0.5]
  });
  const transform = [{
    translateY: interpolate(transition, {
      inputRange: [0, 1],
      outputRange: [500, 0]
    })
  }];

  const share = props => {
    setDetails(props);
    setIsDisplaying(true);
  };

  const close = () => setIsDisplaying(false);

  return /*#__PURE__*/React.createElement(AppearanceProvider, null, /*#__PURE__*/React.createElement(LocalizationProvider, {
    language: language
  }, /*#__PURE__*/React.createElement(ShareContext.Provider, {
    value: {
      share
    }
  }, /*#__PURE__*/React.createElement(View, {
    style: styles.content
  }, /*#__PURE__*/React.createElement(View, {
    style: styles.container
  }, children), /*#__PURE__*/React.createElement(Animated.View, {
    pointerEvents: isDisplaying ? 'auto' : 'none',
    style: [StyleSheet.absoluteFillObject, styles.overlay, {
      opacity
    }]
  }, isDisplaying && /*#__PURE__*/React.createElement(TouchableWithoutFeedback, {
    style: styles.container,
    onPress: close
  }, /*#__PURE__*/React.createElement(View, {
    style: styles.container
  }))), /*#__PURE__*/React.createElement(Animated.View, {
    style: [styles.modal, {
      transform
    }]
  }, /*#__PURE__*/React.createElement(ShareHeader, null), /*#__PURE__*/React.createElement(View, {
    style: [styles.innerContainer, {
      backgroundColor: backgroundPrimary
    }]
  }, /*#__PURE__*/React.createElement(ShareDetails, details), /*#__PURE__*/React.createElement(ButtonRow, {
    types: types,
    details: details,
    close: close
  })))))));
};

const styles = StyleSheet.create({
  container: {
    flex: 1
  },
  content: {
    flex: 1,
    position: 'relative'
  },
  innerContainer: {
    flex: 1,
    paddingBottom: 60
  },
  overlay: {
    flex: 1,
    backgroundColor: 'black'
  },
  modal: {
    position: 'absolute',
    bottom: 0,
    right: 0,
    left: 0
  }
});

const useShare = () => useContext(ShareContext);

export { ShareProvider, useShare };
//# sourceMappingURL=index.js.map